Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 78060)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/exportappliance/UIWizardExportAppPageBasic2.cpp	(revision 78061)
@@ -500,5 +500,5 @@
 void UIWizardExportAppPage2::updatePageAppearance()
 {
-    /* Update page appearance according to chosen storage-type: */
+    /* Update page appearance according to chosen format: */
     m_pSettingsWidget->setCurrentIndex((int)isFormatCloudOne());
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 78060)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 78061)
@@ -54,5 +54,5 @@
 UIWizardImportAppPage1::UIWizardImportAppPage1()
     : m_pSourceLabel(0)
-    , m_pSourceSelector(0)
+    , m_pSourceComboBox(0)
     , m_pStackedLayout(0)
     , m_pFileSelector(0)
@@ -80,7 +80,7 @@
         }
 
-        /* Create source selector layout: */
-        QHBoxLayout *pSourceSelectorLayout = new QHBoxLayout;
-        if (pSourceSelectorLayout)
+        /* Create source layout: */
+        QHBoxLayout *pSourceLayout = new QHBoxLayout;
+        if (pSourceLayout)
         {
             /* Create source label: */
@@ -93,24 +93,24 @@
 
                 /* Add into layout: */
-                pSourceSelectorLayout->addWidget(m_pSourceLabel);
+                pSourceLayout->addWidget(m_pSourceLabel);
             }
 
             /* Create source selector: */
-            m_pSourceSelector = new QIComboBox(this);
-            if (m_pSourceSelector)
-            {
-                m_pSourceLabel->setBuddy(m_pSourceSelector);
-                m_pSourceSelector->hide();
-                m_pSourceSelector->addItem(QString(), QVariant::fromValue(ImportSourceType_Local));
-                m_pSourceSelector->addItem(QString(), QVariant::fromValue(ImportSourceType_Cloud));
-                connect(m_pSourceSelector, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
-                        this, static_cast<void(UIWizardImportAppPageBasic1::*)(int)>(&UIWizardImportAppPageBasic1::sltHandleSourceChange));
-
-                /* Add into layout: */
-                pSourceSelectorLayout->addWidget(m_pSourceSelector);
+            m_pSourceComboBox = new QIComboBox(this);
+            if (m_pSourceComboBox)
+            {
+                m_pSourceLabel->setBuddy(m_pSourceComboBox);
+                m_pSourceComboBox->hide();
+                m_pSourceComboBox->addItem(QString(), QVariant::fromValue(ImportSourceType_Local));
+                m_pSourceComboBox->addItem(QString(), QVariant::fromValue(ImportSourceType_Cloud));
+                connect(m_pSourceComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
+                        this, &UIWizardImportAppPageBasic1::sltHandleSourceChange);
+
+                /* Add into layout: */
+                pSourceLayout->addWidget(m_pSourceComboBox);
             }
 
             /* Add into layout: */
-            pMainLayout->addLayout(pSourceSelectorLayout);
+            pMainLayout->addLayout(pSourceLayout);
         }
 
@@ -182,9 +182,4 @@
 }
 
-void UIWizardImportAppPageBasic1::sltHandleSourceChange(int iIndex)
-{
-    m_pStackedLayout->setCurrentIndex(m_stackedLayoutIndexMap.value(m_pSourceSelector->itemData(iIndex).value<ImportSourceType>()));
-}
-
 void UIWizardImportAppPageBasic1::retranslateUi()
 {
@@ -197,8 +192,10 @@
                                             "To continue, select the file to import below.</p>"));
 
-    /* Translate source selector: */
-    m_pSourceLabel->setText(tr("Source:"));
-    for (int i = 0; i < m_pSourceSelector->count(); ++i)
-        m_pSourceSelector->setItemText(i, ImportSourceTypeConverter::toString(m_pSourceSelector->itemData(i).value<ImportSourceType>()));
+    /* Translate source label: */
+    m_pSourceLabel->setText(tr("&Source:"));
+    /* Translate received values of Source combo-box.
+     * We are enumerating starting from 0 for simplicity: */
+    for (int i = 0; i < m_pSourceComboBox->count(); ++i)
+        m_pSourceComboBox->setItemText(i, ImportSourceTypeConverter::toString(m_pSourceComboBox->itemData(i).value<ImportSourceType>()));
 
     /* Translate file selector: */
@@ -210,4 +207,5 @@
 void UIWizardImportAppPageBasic1::initializePage()
 {
+    /* Translate page: */
     retranslateUi();
 }
@@ -239,2 +237,7 @@
     return pImportApplianceWidget->isValid();
 }
+
+void UIWizardImportAppPageBasic1::sltHandleSourceChange(int iIndex)
+{
+    m_pStackedLayout->setCurrentIndex(m_stackedLayoutIndexMap.value(m_pSourceComboBox->itemData(iIndex).value<ImportSourceType>()));
+}
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 78060)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 78061)
@@ -50,6 +50,6 @@
     /** Holds the source type label instance. */
     QLabel     *m_pSourceLabel;
-    /** Holds the source type selector instance. */
-    QIComboBox *m_pSourceSelector;
+    /** Holds the source type combo-box instance. */
+    QIComboBox *m_pSourceComboBox;
 
     /** Holds the stacked layout instance. */
@@ -72,10 +72,5 @@
     UIWizardImportAppPageBasic1();
 
-private slots:
-
-    /** Handles change of import source to one with specified @a iIndex. */
-    void sltHandleSourceChange(int iIndex);
-
-private:
+protected:
 
     /** Handles translation event. */
@@ -91,4 +86,11 @@
     virtual bool validatePage() /* override */;
 
+private slots:
+
+    /** Handles change of import source to one with specified @a iIndex. */
+    void sltHandleSourceChange(int iIndex);
+
+private:
+
     /** Holds the label instance. */
     QIRichTextLabel *m_pLabel;
